import React, { useEffect, useRef } from 'react';
import * as echarts from 'echarts';

const About = () => {
  const chartRef = useRef(null);

  useEffect(() => {
    const chart = echarts.init(chartRef.current);
    chart.setOption({
      animation: false,
      radar: {
        indicator: [
          { name: '프로그래밍', max: 100 },
          { name: '클라우드', max: 100 },
          { name: '인공지능', max: 100 },
          { name: '데이터 분석', max: 100 },
          { name: '보안', max: 100 }
        ]
      },
      series: [{
        type: 'radar',
        data: [{
          value: [95, 90, 85, 88, 92],
          name: '교육 역량',
          areaStyle: { color: 'rgba(59, 130, 246, 0.2)' },
          lineStyle: { color: '#3B82F6' }
        }]
      }]
    });
  }, []);

  return (
    <div className="min-h-screen bg-white">
      <div className="container mx-auto px-4 py-20">
        <div className="max-w-4xl mx-auto">
          <div className="text-center mb-16">
            <h2 className="text-4xl font-bold mb-6">About Us</h2>
            <p className="text-xl text-gray-600">최고의 IT 교육 플랫폼을 만들어갑니다</p>
          </div>
          <div className="grid grid-cols-1 md:grid-cols-2 gap-12 mb-20">
            <div>
              <h3 className="text-2xl font-bold mb-6">우리의 비전</h3>
              <p className="text-gray-600 leading-relaxed">
                실무 중심의 IT 교육을 통해 더 많은 사람들이 디지털 시대의 전문가로
                성장할 수 있도록 돕고, 글로벌 IT 인재 양성의 허브가 되고자 합니다.
              </p>
            </div>
            <div>
              <h3 className="text-2xl font-bold mb-6">핵심 가치</h3>
              <ul className="space-y-4">
                <li className="flex items-center">
                  <i className="fas fa-check text-[#3B82F6] mr-3"></i><span>실무 중심 교육</span>
                </li>
                <li className="flex items-center">
                  <i className="fas fa-check text-[#3B82F6] mr-3"></i><span>최신 기술 트렌드</span>
                </li>
                <li className="flex items-center">
                  <i className="fas fa-check text-[#3B82F6] mr-3"></i><span>커뮤니티 중심</span>
                </li>
              </ul>
            </div>
          </div>
          <div className="mb-20">
            <h3 className="text-2xl font-bold mb-8 text-center">전문 역량</h3>
            <div ref={chartRef} className="w-full h-[400px]"></div>
          </div>
          <div className="text-center">
            <h3 className="text-2xl font-bold mb-6">Contact Us</h3>
            <div className="space-y-4">
              <p><i className="fas fa-envelope mr-2"></i> contact@example.com</p>
              <p><i className="fas fa-phone mr-2"></i> 02-1234-5678</p>
              <p><i className="fas fa-map-marker-alt mr-2"></i> 서울특별시 강남구 테헤란로 123</p>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default About;