import React, { useState } from 'react';
import { boardItems } from '../data/sampleData';

const Board = () => {
  const [searchTerm, setSearchTerm] = useState('');
  const [currentPage, setCurrentPage] = useState(1);
  const itemsPerPage = 10;

  const filteredItems = boardItems.filter(item =>
    item.title.toLowerCase().includes(searchTerm.toLowerCase()) ||
    item.content.toLowerCase().includes(searchTerm.toLowerCase()) ||
    item.author.toLowerCase().includes(searchTerm.toLowerCase())
  );

  return (
    <div className="min-h-screen bg-gray-50 py-20">
      <div className="container mx-auto px-4">
        <div className="max-w-6xl mx-auto">
          <div className="mb-8">
            <div className="relative">
              <input
                type="text"
                placeholder="검색어를 입력하세요"
                className="w-full px-4 py-3 pl-12 border-none rounded-lg bg-white shadow-md text-sm"
                value={searchTerm}
                onChange={(e) => setSearchTerm(e.target.value)}
              />
              <i className="fas fa-search absolute left-4 top-1/2 -translate-y-1/2 text-gray-400"></i>
            </div>
          </div>
          <div className="bg-white rounded-lg shadow-md overflow-hidden">
            <table className="w-full">
              <thead className="bg-[#3B82F6] text-white">
                <tr>
                  <th className="px-6 py-4 text-left w-20">번호</th>
                  <th className="px-6 py-4 text-left">제목</th>
                  <th className="px-6 py-4 text-left">내용</th>
                  <th className="px-6 py-4 text-left w-32">작성자</th>
                  <th className="px-6 py-4 text-left w-32">수정일</th>
                </tr>
              </thead>
              <tbody>
                {filteredItems
                  .slice((currentPage - 1) * itemsPerPage, currentPage * itemsPerPage)
                  .map(item => (
                    <tr key={item.id} className="border-b border-gray-100 hover:bg-gray-50">
                      <td className="px-6 py-4">{item.id}</td>
                      <td className="px-6 py-4 font-medium">{item.title}</td>
                      <td className="px-6 py-4 text-gray-600">{item.content.substring(0, 30)}...</td>
                      <td className="px-6 py-4">{item.author}</td>
                      <td className="px-6 py-4 text-gray-500">{item.updatedAt}</td>
                    </tr>
                  ))}
              </tbody>
            </table>
          </div>
          <div className="mt-6 flex justify-center">
            <div className="flex space-x-2">
              {Array.from({ length: Math.ceil(filteredItems.length / itemsPerPage) }, (_, i) => (
                <button
                  key={i + 1}
                  onClick={() => setCurrentPage(i + 1)}
                  className={`px-4 py-2 rounded ${
                    currentPage === i + 1
                      ? 'bg-[#3B82F6] text-white'
                      : 'bg-white text-gray-600 hover:bg-gray-100'
                  }`}
                >
                  {i + 1}
                </button>
              ))}
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default Board;